--
-- Definition of table stock_sequences
--

DROP TABLE IF EXISTS stock_sequences;
CREATE TABLE  stock_sequences (
  sequence_name varchar(255) DEFAULT '' NOT NULL,
  next_val BIGINT DEFAULT NULL,
  PRIMARY KEY (sequence_name)
);

--
-- Definition of table stock_basket
--

DROP TABLE IF EXISTS stock_basket;
CREATE TABLE stock_basket (
  id_basket INT DEFAULT '0' NOT NULL,
  id_user INT DEFAULT NULL,
  validated smallint DEFAULT NULL,
  PRIMARY KEY  (id_basket)
);

--
-- Definition of table stock_category
--
DROP TABLE IF EXISTS stock_category;
CREATE TABLE stock_category (
  id_category INT DEFAULT '0' NOT NULL ,
  active smallint DEFAULT NULL,
  name varchar(255) DEFAULT NULL,
  parent_id INT DEFAULT NULL,
  provider_id INT DEFAULT NULL,
  PRIMARY KEY  (id_category)
);
CREATE INDEX FK9792900769015ED5 ON stock_category (provider_id);
CREATE INDEX FK97929007A735EC89 ON stock_category (parent_id);


--
-- Definition of table stock_category_stock_category
--

DROP TABLE IF EXISTS stock_category_stock_category;
CREATE TABLE stock_category_stock_category (
  stock_category_id_category INT DEFAULT '0' NOT NULL,
  childrenList_id_category INT DEFAULT '0' NOT NULL,
  childrenList_ORDER INT DEFAULT '0' NOT NULL,
  PRIMARY KEY  (stock_category_id_category,childrenList_ORDER)
);
CREATE INDEX FK39F77F3F9370C723 ON stock_category_stock_category (stock_category_id_category);
CREATE INDEX FK39F77F3F79EE3D39 ON stock_category_stock_category (childrenList_id_category);

--
-- Definition of table stock_category_stock_product
--

DROP TABLE IF EXISTS stock_category_stock_product;
CREATE TABLE stock_category_stock_product (
  stock_category_id_category INT DEFAULT '0' NOT NULL,
  productSet_id_product INT DEFAULT '0' NOT NULL
);
CREATE INDEX FKBDC73E8E9370C723 ON stock_category_stock_product (stock_category_id_category);
CREATE INDEX FKBDC73E8E6C22A74B ON stock_category_stock_product (productSet_id_product);

--
-- Definition of table stock_days
--

DROP TABLE IF EXISTS stock_days;
CREATE TABLE stock_days (
  TicketProduct_id_product INT DEFAULT '0' NOT NULL,
  day varchar(255) DEFAULT NULL
);
CREATE INDEX FK27ABAFE0A025158F ON stock_days (TicketProduct_id_product);

--
-- Definition of table stock_item
--

DROP TABLE IF EXISTS stock_item;
CREATE TABLE stock_item (
  id_item INT DEFAULT '0' NOT NULL,
  id_product INT DEFAULT NULL,
  price float DEFAULT NULL,
  quantity INT DEFAULT NULL,
  summary varchar(255) DEFAULT NULL,
  id_basket INT DEFAULT '0' NOT NULL,
  PRIMARY KEY  (id_item)
);
CREATE INDEX FK27AE3A9C4E7BAB0B ON stock_item (id_basket);

--
-- Definition of table stock_product
--

DROP TABLE IF EXISTS stock_product;
CREATE TABLE stock_product (
  id_product INT DEFAULT '0' NOT NULL,
  price float DEFAULT NULL,
  stock_quantity INT DEFAULT NULL,
  category_id_category INT DEFAULT NULL,
  PRIMARY KEY  (id_product)
);
CREATE INDEX FK1BA2F4C6FC6A399A ON stock_product (category_id_category);
--
-- Definition of table stock_provider
--

DROP TABLE IF EXISTS stock_provider;
CREATE TABLE stock_provider (
  id_provider INT DEFAULT '0' NOT NULL,
  address varchar(255) DEFAULT NULL,
  comment varchar(255) DEFAULT NULL,
  contactName varchar(255) DEFAULT NULL,
  mail varchar(255) DEFAULT NULL,
  name varchar(255) DEFAULT NULL,
  phone_number varchar(255) DEFAULT NULL,
  PRIMARY KEY  (id_provider)
);

--
-- Definition of table stock_provider_stock_category
--

DROP TABLE IF EXISTS stock_provider_stock_category;
CREATE TABLE stock_provider_stock_category (
  stock_provider_id_provider INT DEFAULT '0' NOT NULL,
  products_id_category INT DEFAULT '0' NOT NULL
);
CREATE INDEX FKF592D1EC8CC9E500 ON stock_provider_stock_category (products_id_category);
CREATE INDEX FKF592D1ECF087CD7C ON stock_provider_stock_category (stock_provider_id_provider);

--
-- Definition of table stock_ticket_category
--

DROP TABLE IF EXISTS stock_ticket_category;
CREATE TABLE stock_ticket_category (
  booking_mail varchar(255) DEFAULT NULL,
  booking_phone varchar(255) DEFAULT NULL,
  id_category INT DEFAULT '0' NOT NULL,
  PRIMARY KEY  (id_category)
);
CREATE INDEX FK82B091A8B2B4AB5B ON stock_ticket_category (id_category);

--
-- Definition of table stock_ticket_product
--

DROP TABLE IF EXISTS stock_ticket_product;
CREATE TABLE stock_ticket_product (
  date_begin datetime DEFAULT NULL,
  date_end datetime DEFAULT NULL,
  duration INT DEFAULT NULL,
  hour datetime DEFAULT NULL,
  id_product INT DEFAULT '0' NOT NULL,
  PRIMARY KEY  (id_product)
);


CREATE INDEX FKB7DDBB05AF21409F ON stock_ticket_product (id_product);

ALTER TABLE stock_category ADD CONSTRAINT FK97929007A735EC89 FOREIGN KEY (parent_id) REFERENCES stock_category (id_category);
ALTER TABLE stock_category ADD CONSTRAINT FK9792900769015ED5 FOREIGN KEY (provider_id) REFERENCES stock_provider (id_provider);

ALTER TABLE stock_category_stock_category ADD UNIQUE (childrenList_id_category);
ALTER TABLE stock_category_stock_category ADD CONSTRAINT FK39F77F3F79EE3D39 FOREIGN KEY (childrenList_id_category) REFERENCES stock_category (id_category);
ALTER TABLE stock_category_stock_category ADD CONSTRAINT FK39F77F3F9370C723 FOREIGN KEY (stock_category_id_category) REFERENCES stock_category (id_category);

ALTER TABLE stock_category_stock_product ADD UNIQUE (productSet_id_product);
ALTER TABLE stock_category_stock_product ADD CONSTRAINT FKBDC73E8E6C22A74B FOREIGN KEY (productSet_id_product) REFERENCES stock_product (id_product);
ALTER TABLE stock_category_stock_product ADD CONSTRAINT FKBDC73E8E9370C723 FOREIGN KEY (stock_category_id_category) REFERENCES stock_category (id_category);

ALTER TABLE stock_days ADD CONSTRAINT FK27ABAFE0A025158F FOREIGN KEY (TicketProduct_id_product) REFERENCES stock_ticket_product (id_product);

ALTER TABLE stock_item ADD CONSTRAINT FK27AE3A9C4E7BAB0B FOREIGN KEY (id_basket) REFERENCES stock_basket (id_basket);

ALTER TABLE stock_product ADD CONSTRAINT FK1BA2F4C6FC6A399A FOREIGN KEY (category_id_category) REFERENCES stock_category (id_category);

ALTER TABLE stock_provider_stock_category ADD UNIQUE (products_id_category);
ALTER TABLE stock_provider_stock_category ADD CONSTRAINT FKF592D1ECF087CD7C FOREIGN KEY (stock_provider_id_provider) REFERENCES stock_provider (id_provider);
ALTER TABLE stock_provider_stock_category ADD CONSTRAINT FKF592D1EC8CC9E500 FOREIGN KEY (products_id_category) REFERENCES stock_category (id_category);

ALTER TABLE stock_ticket_category ADD CONSTRAINT FK82B091A8B2B4AB5B FOREIGN KEY (id_category) REFERENCES stock_category (id_category);

ALTER TABLE stock_ticket_product ADD CONSTRAINT FKB7DDBB05AF21409F FOREIGN KEY (id_product) REFERENCES stock_product (id_product);
